# Cipher-symmetric

## The modern python based encryption and decryption utility

Cipher is a python CLI utility for encryption and decryption of strings using the cryptography module of python(symmetric encryption).

Installation:

Linux and Mac:
```sh
pip3 install cipher-symmetric

# via git
pip3 install git+https://github.com/Programming-geek582/encipher.git
```

Windows:
```bat
pip install cipher-symmetric

# via git
pip install git+https://github.com/Programming-geek582/encipher.git
```

Usage:

```sh
# Windows
cipher or python -m cipher

# Linux and mac
cipher or python3 -m cipher
```

Happy encrypting!

***Note: the private key is saved in a weird file format, dont try to mess with that or you wont be able to decrypt the content ever again***
